@@ -15,17 +15,29 @@ class Worker:
         self.args_names = args_names
 
     def start(self):
-        print(" [x] En attente de requêtes")
-        self.channel.start_consuming()
+        try:
+            # Your normal block of code
+
+            print(" [x] En attente de requêtes")
+            self.channel.start_consuming()
+        except KeyboardInterrupt:
+            print("\nDéconnection")
+            self.channel.stop_consuming()
 
     def on_request(self, ch, method, props, body):
+        print(" [x] Processing request")
         list_args = json.loads(body.decode())
         dict_args = {}
         index = 0
         for arg in list_args:
             dict_args[self.args_names[index]] = arg
             index += 1
-        response = json.dumps(self.callback(dict_args))
+        try:
+            response = json.dumps({"data": self.callback(dict_args), "status": "ok"})
+
+        except Exception as inst:
+            print(inst)
+            response = json.dumps({"status": "error"})
         ch.basic_publish(
             exchange="",
             routing_key=props.reply_to,
@@ -33,3 +45,4 @@ class Worker:
             body=str(response),
         )
         ch.basic_ack(delivery_tag=method.delivery_tag)
+        print(" [X] End of processing")
